==> org.eclipse.riena.navigation.ui.swt.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/internal/navigation/ui/swt/handlers/CloseModuleGroup.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.internal.navigation.ui.swt.handlers;

import java.util.List;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;

import org.eclipse.riena.navigation.ApplicationNodeManager;
import org.eclipse.riena.navigation.IApplicationNode;
import org.eclipse.riena.navigation.IModuleGroupNode;
import org.eclipse.riena.navigation.IModuleNode;
import org.eclipse.riena.navigation.INavigationNode;

/**
 * Close the currently active module-group.
 */
public class CloseModuleGroup extends AbstractNavigationHandler {

	public Object execute(ExecutionEvent event) throws ExecutionException {
		// assumes there is only one application node
		IApplicationNode application = ApplicationNodeManager.getApplicationNode();
		IModuleGroupNode moduleGroup = findModuleGroup(application);
		if (moduleGroup != null && isCloseable(moduleGroup)) {
			INavigationNode<?> previous = findPreviousModuleGroup(moduleGroup);
			if (previous != null) {
				previous.activate();
			}
			moduleGroup.dispose();
		}
		return null;
	}

	// helping methods
	//////////////////

	private INavigationNode<?> findPreviousModuleGroup(IModuleGroupNode moduleGroup) {
		List<?> moduleGroups = moduleGroup.getParent().getChildren();
		INavigationNode<?>[] nodes = moduleGroups.toArray(new INavigationNode<?>[moduleGroups.size()]);
		return findPreviousNode(nodes, false);
	}

	private boolean isCloseable(IModuleGroupNode moduleGroup) {
		boolean result = true;
		for (IModuleNode module : moduleGroup.getChildren()) {
			result = result && module.isClosable();
		}
		return result;
	}

}

==> org.eclipse.riena.navigation.ui.swt.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/internal/navigation/ui/swt/handlers/CloseModuleGroup.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.internal.navigation.ui.swt.handlers;

import java.util.List;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;

import org.eclipse.riena.navigation.ApplicationNodeManager;
import org.eclipse.riena.navigation.IApplicationNode;
import org.eclipse.riena.navigation.IModuleGroupNode;
import org.eclipse.riena.navigation.IModuleNode;
import org.eclipse.riena.navigation.INavigationNode;

/**
 * Close the currently active module-group.
 */
public class CloseModuleGroup extends AbstractNavigationHandler {

	public Object execute(final ExecutionEvent event) throws ExecutionException {
		// assumes there is only one application node
		final IApplicationNode application = ApplicationNodeManager.getApplicationNode();
		final IModuleGroupNode moduleGroup = findModuleGroup(application);
		if (moduleGroup != null && isCloseable(moduleGroup)) {
			final INavigationNode<?> previous = findPreviousModuleGroup(moduleGroup);
			if (previous != null) {
				previous.activate();
			}
			moduleGroup.dispose();
		}
		return null;
	}

	// helping methods
	//////////////////

	private INavigationNode<?> findPreviousModuleGroup(final IModuleGroupNode moduleGroup) {
		final List<?> moduleGroups = moduleGroup.getParent().getChildren();
		final INavigationNode<?>[] nodes = moduleGroups.toArray(new INavigationNode<?>[moduleGroups.size()]);
		return findPreviousNode(nodes, false);
	}

	private boolean isCloseable(final IModuleGroupNode moduleGroup) {
		boolean result = true;
		for (final IModuleNode module : moduleGroup.getChildren()) {
			result = result && module.isClosable();
		}
		return result;
	}

}
